@@ -451,15 +451,23 @@ class AzureBlobFileSystem(AsyncFileSystem):
         str
             Returns a path without the protocol
         """
+        STORE_SUFFIX = ".dfs.core.windows.net"
         logger.debug(f"_strip_protocol for {path}")
+        if not path.startswith(("abfs://", "az://", "abfss://")):
+            path = path.lstrip("/")
+            path = "abfs://" + path
         ops = infer_storage_options(path)
-
+        if "username" in ops:
+            if ops.get("username", None):
+                ops["path"] = ops["username"] + ops["path"]
         # we need to make sure that the path retains
         # the format {host}/{path}
         # here host is the container_name
-        if ops.get("host", None):
-            ops["path"] = ops["host"] + ops["path"]
-        ops["path"] = ops["path"].lstrip("/")
+        elif ops.get("host", None):
+            if (
+                ops["host"].count(STORE_SUFFIX) == 0
+            ):  # no store-suffix, so this is container-name
+                ops["path"] = ops["host"] + ops["path"]
 
         logger.debug(f"_strip_protocol({path}) = {ops}")
         return ops["path"]
@@ -1327,26 +1335,13 @@ class AzureBlobFileSystem(AsyncFileSystem):
                 if fp["name"] != path:
                     return True
         try:
-            container_name, path = self.split_path(path)
-            if not path:
+            container_name, path_ = self.split_path(path)
+            if not path_:
                 return await self._container_exists(container_name)
             else:
-                path = path.strip("/")
-                key = path + "/"
-                key_length = len(key)
-                async with self.service_client.get_container_client(
-                    container_name
-                ) as cc:
-                    blob_pages = cc.list_blobs(name_starts_with=key)
-                    async for blob in blob_pages:
-                        if (blob["metadata"].get("is_directory", None) == "true") and (
-                            blob["name"] == path
-                        ):
-                            return True
-                        if (blob.name[:key_length] == key) and (
-                            len(blob["name"]) > len(key)
-                        ):
-                            return True
+                if await self._exists(path) and not await self._isfile(path):
+                    return True
+                else:
                     return False
         except IOError:
             return False
